@@ -2,18 +2,20 @@ use strict;
 use warnings;
 package Plack::Middleware::Auth::Form;
 BEGIN {
-  $Plack::Middleware::Auth::Form::VERSION = '0.008';
+  $Plack::Middleware::Auth::Form::VERSION = '0.009';
 }
 
 use parent qw/Plack::Middleware/;
 use Plack::Util::Accessor qw( secure authenticator no_login_page after_logout );
 use Plack::Request;
 use Scalar::Util;
+use Carp ();
+
 
 sub prepare_app {
     my $self = shift;
 
-    my $auth = $self->authenticator or die 'authenticator is not set';
+    my $auth = $self->authenticator or Carp::croak 'authenticator is not set';
     if (Scalar::Util::blessed($auth) && $auth->can('authenticate')) {
         $self->authenticator(sub { $auth->authenticate(@_[0,1]) }); # because Authen::Simple barfs on 3 params
     } elsif (ref $auth ne 'CODE') {
@@ -49,7 +51,7 @@ sub _login {
         my $secure_url = "https://$server" . $env->{PATH_INFO};
         return [ 
             301, 
-            { Location => $secure_url }, 
+            [ Location => $secure_url ],
             [ "<html><body><a href=\"$secure_url\">Need a secure connection</a></body></html>" ]
         ];
     }
@@ -76,7 +78,7 @@ sub _login {
                 URI->new( $redir_to )->path eq $env->{PATH_INFO};
             return [ 
                 302, 
-                { Location => $redir_to }, 
+                [ Location => $redir_to ],
                 [ "<html><body><a href=\"$redir_to\">Back</a></body></html>" ]
             ];
         }
@@ -88,13 +90,13 @@ sub _login {
         redir_to => $env->{'psgix.session'}{redir_to},
     );
     if( $self->no_login_page ){
-        $env->{SimpleLoginForm} = $form;
+        $env->{'Plack::Middleware::Auth::Form.LoginForm'} = $form;
         return $self->app->( $env );
     }
     else{
          return [ 
             200, 
-            { 'Content-Type' => 'text/html', },
+            [ 'Content-Type' => 'text/html', ],
             [ "<html><body>$form\nAfter login: $env->{'psgix.session'}{redir_to}</body></html>" ]
         ];
     }
@@ -128,7 +130,7 @@ sub _logout {
     }
     return [ 
         303, 
-        { Location => $self->after_logout || '/' }, 
+        [ Location => $self->after_logout || '/' ],
         [ "<html><body><a href=\"/\">Home</a></body></html>" ]
     ];
 }
@@ -145,7 +147,7 @@ Plack::Middleware::Auth::Form - Form Based Authentication for Plack (think L<Cat
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 SYNOPSIS
 
@@ -178,7 +180,8 @@ a hashref from the C<authenticator> callback described below.
 
 If the login page looks too simplistic - the application can take over
 displaying it by setting the C<no_login_page> attribute.  Then 
-the the login form will be saved to C<< $env->{SimpleLoginForm} >>.
+the the login form will be saved to 
+C<< $env->{'Plack::Middleware::Auth::Form.LoginForm'} >>.
 
 =head1 CONFIGURATION
 
@@ -202,7 +205,8 @@ to be saved in the session instead of the username.
 
 =item no_login_page
 
-Save the login form on C<< $env->{SimpleLoginForm} >> and let the 
+Save the login form on C<< $env->{'Plack::Middleware::Auth::Form.LoginForm'} >> 
+and let the 
 application display the login page (for a GET request).
 
 =item after_logout
